"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Cli = void 0;
const tslib_1 = require("tslib");
const commander_1 = require("commander");
const inversify_1 = require("inversify");
const kleur_1 = tslib_1.__importDefault(require("kleur"));
const figlet_1 = tslib_1.__importDefault(require("figlet"));
const types_1 = require("../types");
const format_1 = require("../model/format");
const pkg = require('../../package.json');
let Cli = class Cli {
    constructor(_fileParser) {
        this._fileParser = _fileParser;
        this._MINIMUM_ARG_SIZE = 2;
    }
    main(argv) {
        console.log(kleur_1.default.red(figlet_1.default.textSync('coboldoc', { horizontalLayout: 'full' })));
        const command = new commander_1.Command();
        command.option('-o, --output <outputDirectory>', 'The output directory', process.cwd())
            .option('-f, --format <fileFormat>', 'Suported output format: md, html', 'md');
        command.version(pkg.version, '-v, --version')
            .usage('<command> [options]');
        command.command('generate <files...>')
            .description('generate the documentation')
            .action((files) => {
            this._fileParser.parse(files, command.output, format_1.Format[command.format.toUpperCase()]);
        });
        command.parse(argv);
        if (argv.length <= this._MINIMUM_ARG_SIZE) {
            command.help();
        }
    }
};
Cli = tslib_1.__decorate([
    inversify_1.injectable(),
    tslib_1.__param(0, inversify_1.inject(types_1.TYPES.FileParser)),
    tslib_1.__metadata("design:paramtypes", [Object])
], Cli);
exports.Cli = Cli;
