#!/usr/bin/env node
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.init = void 0;
require("reflect-metadata");
const inversify_1 = require("inversify");
const cli_1 = require("./controllers/cli");
const types_1 = require("./types");
const file_parser_1 = require("./services/file-parser");
const template_engine_1 = require("./services/template-engine");
const file_output_stream_1 = require("./services/file-output-stream");
const documentation_extractor_1 = require("./services/documentation-extractor");
function init() {
    const container = new inversify_1.Container();
    container.bind(types_1.TYPES.FileOutputStream).to(file_output_stream_1.FileOutputStreamImpl).inSingletonScope();
    container.bind(types_1.TYPES.TemplateEngine).to(template_engine_1.TemplateEngineImpl).inSingletonScope();
    container.bind(types_1.TYPES.DocumentationExtractor).to(documentation_extractor_1.DocumentationExtractorImpl).inSingletonScope();
    container.bind(types_1.TYPES.FileParser).to(file_parser_1.FileParserImpl).inSingletonScope();
    container.bind(types_1.TYPES.Cli).to(cli_1.Cli).inSingletonScope();
    return container.get(types_1.TYPES.Cli);
}
exports.init = init;
const app = init();
app.main(process.argv);
