"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DocumentationExtractorImpl = void 0;
const tslib_1 = require("tslib");
const inversify_1 = require("inversify");
const fs = tslib_1.__importStar(require("fs"));
const path = tslib_1.__importStar(require("path"));
let DocumentationExtractorImpl = class DocumentationExtractorImpl {
    constructor() { }
    extract(filePath) {
        const data = fs.readFileSync(filePath, 'utf8');
        const lines = data.split(/\r?\n/);
        let comments = [];
        const fileComments = [];
        let isFileComments = false;
        let isComments = false;
        const functions = [];
        const modules = [];
        let lineCounter = 1;
        lines.forEach((line) => {
            if (/^\s*\*\>[^*].*/.test(line)) {
                if (isFileComments) {
                    fileComments.push(line);
                }
                if (isComments) {
                    comments.push(line);
                }
            }
            else if (/^\s*\*\>\*\*.*/.test(line)) {
                fileComments.push(line);
                isFileComments = !isFileComments;
                isComments = false;
            }
            else if (/^\s*\*\>\*.*/.test(line)) {
                comments.push(line);
                isComments = !isComments;
                isFileComments = false;
            }
            else if (/^\s*function-id\..+/i.test(line)) {
                functions.push(this._extractModuleOrFunction(line, lineCounter, comments));
                comments = [];
            }
            else if (/^\s*program-id\..+/i.test(line)) {
                modules.push(this._extractModuleOrFunction(line, lineCounter, comments));
                comments = [];
            }
            lineCounter++;
        });
        const [fileDescription, author, license] = this._extractFileDetails(fileComments);
        return {
            fileName: path.basename(filePath),
            fileDescription: fileDescription,
            author: author,
            license: license,
            functions: functions,
            modules: modules,
        };
    }
    _extractModuleOrFunction(line, lineNumber, comments) {
        const name = line.split(".")[1].trim();
        const rawText = this._cleanComments(comments);
        const pieces = rawText.split('@');
        const params = [];
        let returnObj = undefined;
        let description = undefined;
        let summary = undefined;
        pieces.forEach((piece, index) => {
            if (index === 0) {
                description = piece;
                summary = piece;
            }
            else if (/^summary/.test(piece)) {
                summary = piece.substring(piece.indexOf(' ') + 1);
            }
            else if (/^param/.test(piece)) {
                piece = piece.substring(piece.indexOf(' ') + 1);
                let paramType = undefined;
                const match = piece.match(/\{(.+)\}/);
                if (!!match) {
                    paramType = match[1];
                    piece = piece.replace(/\{(.+)\}/, '').trim();
                }
                const paramName = piece.substring(0, piece.indexOf(' '));
                const paramDescription = piece.substring(piece.indexOf(' ') + 1).trim();
                params.push({
                    name: paramName,
                    description: paramDescription,
                    type: paramType,
                });
            }
            else if (/^return/.test(piece)) {
                let returnType = undefined;
                const match = piece.match(/\{(.+)\}/);
                if (!!match) {
                    returnType = match[1];
                    piece = piece.replace(/\{(.+)\}/, '').trim();
                }
                const returnDescription = piece.substring(piece.indexOf(' ') + 1).trim();
                returnObj = {
                    description: returnDescription,
                    type: returnType,
                };
            }
        });
        return {
            description: description,
            line: lineNumber,
            name: name,
            paragraphs: [],
            params: params,
            return: returnObj,
            summary: summary
        };
    }
    _extractFileDetails(comments) {
        const rawText = this._cleanComments(comments);
        const pieces = rawText.split('@');
        let author = undefined;
        let license = undefined;
        let description = undefined;
        pieces.forEach((piece, index) => {
            if (index === 0) {
                description = piece.trim();
            }
            else if (/^license/.test(piece)) {
                license = piece.substring(piece.indexOf(' ')).trim();
            }
            else if (/^author/.test(piece)) {
                author = piece.substring(piece.indexOf(' ')).trim();
            }
        });
        return [description, author, license];
    }
    _cleanComments(comments) {
        return comments
            .map(comment => comment.replace(/^\s*\*>\**\s*/, ''))
            .filter(comment => comment.length !== 0)
            .join('\n');
    }
};
DocumentationExtractorImpl = tslib_1.__decorate([
    inversify_1.injectable(),
    tslib_1.__metadata("design:paramtypes", [])
], DocumentationExtractorImpl);
exports.DocumentationExtractorImpl = DocumentationExtractorImpl;
