"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.FileParserImpl = void 0;
const tslib_1 = require("tslib");
const inversify_1 = require("inversify");
const path = tslib_1.__importStar(require("path"));
const types_1 = require("../types");
const format_1 = require("../model/format");
const kleur_1 = tslib_1.__importDefault(require("kleur"));
let FileParserImpl = class FileParserImpl {
    constructor(_documentationExtractor, _templateEngine, _outputStream) {
        this._documentationExtractor = _documentationExtractor;
        this._templateEngine = _templateEngine;
        this._outputStream = _outputStream;
    }
    parse(files, outputDirectory, format) {
        console.log(`Output directory: ${outputDirectory}`);
        console.log(`Selected format: ${format}`);
        const exportedFiles = [];
        files.forEach(file => {
            this._parseFile(file, outputDirectory, format, exportedFiles);
        });
        const tableOfContents = format_1.TableOfContents.from(format);
        process.stdout.write(`Generating ${tableOfContents}... `);
        const outputContent = this._templateEngine.parseTableOfContents(format, exportedFiles);
        this._outputStream.write(outputDirectory, tableOfContents, outputContent);
        console.log(kleur_1.default.green('DONE'));
    }
    _parseFile(file, outputDirectory, format, exportedFiles) {
        const filePath = this._defineFilePath(file);
        const baseName = path.basename(filePath);
        const exportedFileName = `${baseName}.${format}`;
        process.stdout.write(`Generating ${baseName} documentation... `);
        const documentation = this._documentationExtractor.extract(filePath);
        const outputContent = this._templateEngine.parseDocumentation(format, documentation);
        this._outputStream.write(outputDirectory, exportedFileName, outputContent);
        console.log(kleur_1.default.green('DONE'));
        exportedFiles.push(exportedFileName);
    }
    _defineFilePath(file) {
        let filePath = file;
        if (!path.isAbsolute(file)) {
            filePath = path.join(process.cwd(), file);
        }
        return filePath;
    }
};
FileParserImpl = tslib_1.__decorate([
    inversify_1.injectable(),
    tslib_1.__param(0, inversify_1.inject(types_1.TYPES.DocumentationExtractor)),
    tslib_1.__param(1, inversify_1.inject(types_1.TYPES.TemplateEngine)),
    tslib_1.__param(2, inversify_1.inject(types_1.TYPES.FileOutputStream)),
    tslib_1.__metadata("design:paramtypes", [Object, Object, Object])
], FileParserImpl);
exports.FileParserImpl = FileParserImpl;
